==> ann-0.3.tar.gz: ann-0.3/lib/ann_w_delta.cpp <==
/***************************************************************************
                          ann_w_delta.cpp  -  description
                             -------------------
    begin                : pon kwi 14 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <ann_w_delta.h>

  //               //
 // class W_delta //
//               //

ANN::W_delta::~W_delta()
{
}

void
ANN::W_delta::prepare(TO &t)
{
  size_t i, l=d.get_size();
  for (i=0; i<l; ++i) d.get_data()[i]=0;
}

void
ANN::W_delta::adapt(const Term &d_)
{
  size_t i, l=d.get_size();
  for (i=0; i<l; ++i) d.get_data()[i]+=d_.get_data()[i];
}

void
ANN::W_delta::update(TO &t)
{
  size_t i, l=w.get_size();
  for (i=0; i<l; ++i)
  {
    w.get_data()[i]+=d.get_data()[i];
    d.get_data()[i]=0;
  }
}

==> ann-0.4.tar.gz: ann-0.4/lib/ann_w_delta.cpp <==
/***************************************************************************
                          ann_w_delta.cpp  -  description
                             -------------------
    begin                : pon kwi 14 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <ann_w_delta.h>

  //               //
 // class W_delta //
//               //

ANN::W_delta::~W_delta()
{
}

void
ANN::W_delta::commence(NE &ne)
{
  size_t i, l=d.get_size();
  for (i=0; i<l; ++i) d.get_data()[i]=0;
}

void
ANN::W_delta::feed_back(const Term &d_)
{
  size_t i, l=d.get_size();
  for (i=0; i<l; ++i) d.get_data()[i]+=d_.get_data()[i];
}

void
ANN::W_delta::commit(NE &ne)
{
  size_t i, l=w.get_size();
  for (i=0; i<l; ++i)
  {
    w.get_data()[i]+=d.get_data()[i];
    d.get_data()[i]=0;
  }
}
